@@ -8,6 +8,7 @@ import os
 import matplotlib.pyplot as plt
 import numpy as np
 import geopandas as gpd
+import configparser
 from emipy import processdata
 
 
@@ -106,6 +107,7 @@ def get_PollutantVolumeChange(db, FirstOrder=None, SecondOrder=None):
     for items in data.columns:
         if items != FirstOrder:
             data[items] = data[items].diff()
+    data = data.iloc[1:]
     return data
 
 
@@ -117,7 +119,7 @@ def plot_PollutantVolume(db, FirstOrder=None, SecondOrder=None, stacked=False, *
     Parameters
     ----------
     db : DataFrame
-        DESCRIPTION.
+        The data to be plotted.
     FirstOrder : String, optional
         Name of column, the data are sorted in the first order. The default is None.
     SecondOrder : String, optional
@@ -131,7 +133,8 @@ def plot_PollutantVolume(db, FirstOrder=None, SecondOrder=None, stacked=False, *
 
     Returns
     -------
-    Plot
+    ax : Axes
+        Plot of the data in db, sorted by FirstOrder and SecondOrder if given.
 
     """
     data = get_PollutantVolume(db, FirstOrder=FirstOrder, SecondOrder=SecondOrder)
@@ -144,6 +147,7 @@ def plot_PollutantVolume(db, FirstOrder=None, SecondOrder=None, stacked=False, *
             ax = data.plot.bar(x=FirstOrder, *args, **kwargs)
     return(ax)
 
+
 def plot_PollutantVolumeChange(db, FirstOrder=None, SecondOrder=None, stacked=False, *args, **kwargs):
     """
     Plots the volume change of the data set. The first order is the x-axis, the second order is a differentiation of the y-values.
@@ -151,7 +155,7 @@ def plot_PollutantVolumeChange(db, FirstOrder=None, SecondOrder=None, stacked=Fa
     Parameters
     ----------
     db : DataFrame
-        DESCRIPTION.
+        The data to be plotted.
     FirstOrder : String, optional
         Name of column, the data are sorted in the first order. The default is None.
     SecondOrder : String, optional
@@ -165,7 +169,8 @@ def plot_PollutantVolumeChange(db, FirstOrder=None, SecondOrder=None, stacked=Fa
 
     Returns
     -------
-    Plot
+    ax : Axes
+        Plot of the data in db, sorted by FirstOrder and SecondOrder if given.
 
     """
     data = get_PollutantVolumeChange(db, FirstOrder=FirstOrder, SecondOrder=SecondOrder)
@@ -186,7 +191,7 @@ def plot_PollutantVolume_rel(db, FirstOrder=None, SecondOrder=None, stacked=Fals
     Parameters
     ----------
     db : DataFrame
-        DESCRIPTION.
+        The data to be plotted.
     FirstOrder : String, optional
         Name of column, the data are sorted in the first order. The default is None.
     SecondOrder : String, optional
@@ -202,7 +207,8 @@ def plot_PollutantVolume_rel(db, FirstOrder=None, SecondOrder=None, stacked=Fals
 
     Returns
     -------
-    Plot
+    ax : Axes
+        Plot of the data in db, sorted by FirstOrder and SecondOrder if given.
 
     """
     data = get_PollutantVolume_rel(db, FirstOrder=FirstOrder, SecondOrder=SecondOrder, norm=norm)
@@ -234,7 +240,8 @@ def get_mb_borders(mb):
     borders = (foo.minx.min(), foo.miny.min(), foo.maxx.max(), foo.maxy.max())
     return list(borders)
 
-def excludeData_NotInBorders(borders,gdf):
+
+def excludeData_NotInBorders(borders, gdf):
     """
     seperates data, that are inside and outside given borders
 
@@ -247,7 +254,10 @@ def excludeData_NotInBorders(borders,gdf):
 
     Returns
     -------
-    [1] GeoDataFrame with data inside the borders. [2] GeoDataFrame with data outside the borders.
+    gdft : DataFrame
+        GeoDataFrame with data inside the borders.
+    gdff : DataFrame
+        GeoDataFrame with data outside the borders.
 
     """
     gdft = gdf
@@ -286,7 +296,7 @@ def add_markersize(gdf, maxmarker):
     return gdf
 
 
-def map_PollutantSource(db, mb, category=None, markersize=0, *args, **kwargs):
+def map_PollutantSource(db, mb, category=None, markersize=0, ReturnMarker=0, *args, **kwargs):
     """
     maps pollutant sources given by db on map given by mb.
 
@@ -300,10 +310,12 @@ def map_PollutantSource(db, mb, category=None, markersize=0, *args, **kwargs):
         The column name of db, which gets new colors for every unique entry.
     markersize : Int
         maximal size of the largest marker.
+    ReturnMarker : Int
+        If put on 1, the function returns a DataFrame with all data that are plotted. If put on 2, the function returns a DataFrame with all data  that are not plotted, because their coordinates are outside the geo borders.
     *args : TYPE
-        Geopandas.plot() input variables.
+        Geopandas.plot() input arguments.
     **kwargs : TYPE
-        Geopandas.plot() input variables.
+        Geopandas.plot() input arguments.
 
     Returns
     -------
@@ -312,7 +324,7 @@ def map_PollutantSource(db, mb, category=None, markersize=0, *args, **kwargs):
     gdfp : GeoDataFrame
         GeoDataFrame with all sources that are within geo borders and therefore plotted.
     gdfd : GeoDataFrame
-        GeoDataFrame with all sources that are outside geo borders and there fore
+        GeoDataFrame with all sources that are outside geo borders and therefore dropped.
 
     """
 # color selecting is bad.
@@ -344,7 +356,12 @@ def map_PollutantSource(db, mb, category=None, markersize=0, *args, **kwargs):
         print('Some data points are out of borders')
     else:
         print('All data points are within rectangular borders')
-    return(ax, gdfp, gdfd)
+    if ReturnMarker == 0:
+        return(ax)
+    elif ReturnMarker == 1:
+        return(gdfp)
+    else:
+        return(gdfd)
 
 
 def map_PollutantRegions(db, mb, *args, **kwargs):
@@ -358,9 +375,9 @@ def map_PollutantRegions(db, mb, *args, **kwargs):
     mb : TYPE
         Map data for plotting. The region selection corresponds to the selection of mb.
     *args : TYPE
-        Geopandas.plot() input variables.
+        Geopandas.plot() input arguments.
     **kwargs : TYPE
-        Geopandas.plot() input variables.
+        Geopandas.plot() input arguments.
 
     Returns
     -------
@@ -373,3 +390,35 @@ def map_PollutantRegions(db, mb, *args, **kwargs):
     db02 = pd.merge(mb, db01, how='left', on=['NUTS_ID'])
     ax = db02.plot(column='TotalQuantity', *args, **kwargs)
     return(ax)
+
+
+def export_fig(fig, path=None, filename=None, **kwargs):
+    """
+    Exports the choosen figure to a given path or to the export folder of the project if no path is given.
+
+    Parameters
+    ----------
+    fig : figure
+        The figure that is to export.
+    path : String, optional
+        Path under which the file is stored. The filename has to be included. The default is None.
+    filename : String, optional
+        Filename under which the figure is stored in the Export folder of the project. The default is None.
+    **kwargs : TYPE
+        Matplotlib.savefig() input arguments.
+
+    Returns
+    -------
+    None.
+
+    """
+    if (path==None and filename==None):
+        print('A filename is required.')
+        return None
+    if path==None:
+        config = configparser.ConfigParser()
+        config.read(os.path.join(os.path.dirname(os.path.realpath(__file__)), 'configuration\\configuration.ini'))       
+        path = config['PATH']['path']
+        path = os.path.join(os.path.join(path, 'ExportData'), filename)
+    fig.savefig(path, **kwargs)
+    return None
